import pytz
import datetime as dt

def msconverttz(ms, tz):
    """Pass a millisecond utc timestamp (ms) and a timezone information (tz) to return datetime.
        :param ms: Unix UTC timestamp in milliseconds
        :param tz: timezone info
        :return: timezone aware datetime
    """

    utc_datetime = dt.datetime.utcfromtimestamp(ms / 1000.)
    dt_final = utc_datetime.replace(tzinfo=pytz.timezone('UTC')).astimezone(tz)

    return dt_final


from setuptools import setup, find_packages

setup(
    name='ms-to-datetime',
    version='0.0.3',
    description='Convert from ms to datetime',
    url='',
    author='Felipe Viana',
    author_email='',
    license='MIT',
    classifiers=["Programming Language :: Python :: 3",
                 "License :: OSI Approved :: MIT License",
                 "Operating System :: OS Independent"],
    keywords='',
    packages=find_packages(),
    install_requires=['pytz','datetime']
   
)